<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\Storelocator\Controller\Index;

/**
 * Responsible for loading page content.
 *
 * This is a basic controller that only loads the corresponding layout file. It may duplicate other such
 * controllers, and thus it is considered tech debt. This code duplication will be resolved in future releases.
 */
class StoresByCurrentZoom extends \Magento\Framework\App\Action\Action
{
    /** @var \Magento\Framework\Controller\Result\JsonFactory */
    protected $jsonResultFactory;

    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
    )
    {
        parent::__construct($context);
        $this->resultJsonFactory = $resultJsonFactory;
    }

    public function execute()
    {

        $params = $this->getRequest()->getParams();

        if ($params["ajax"] == 1 && $this->getRequest()->isXmlHttpRequest()) {
            $resultJson = $this->resultJsonFactory->create();

            $model = \Magento\Framework\App\ObjectManager::getInstance()->get('FiloBlu\Storelocator\Model\Stores');
            $collection = $model->getStoresByCurrentZoom($params["lat1"], $params["lng1"], $params["lat2"], $params["lng2"]);

            $loadedMarkers = array_filter(explode("_", $params["loadedMarkers"]));

            if (count($loadedMarkers)) {
                $collection->addFieldToFilter('store_id', ["nin" => $loadedMarkers]);
            }

            $res = [];

            if ($resCount = $collection->count()) {
                $res["totalRecords"] = $collection->count();
                foreach ($collection as $item) {
                    $res["items"][] = $item->getData();
                }

            }

            $resultJson->setData($res);

            return $resultJson;
        } else {
            return null;
        }
    }
}